@@ -7,15 +7,27 @@ markdown_to_html <- function(text) {
 }
 
 # Convert List Names from Markdown to HTML
-list_name_md_to_html <- function(list) {
-  list_names_md <- names(list)
-  list_names_html <- lapply(list_names_md, function(name) {
+choice_html <- function(option) {
+  choice_names_md <- names(option)
+  choice_names_html <- lapply(choice_names_md, function(name) {
     html_name <- markdown_to_html(name)
-    plain_name <- gsub("<[/]?p>|\\n", "", html_name)
-    return(plain_name)
+    clean_name <- gsub("<[/]?p>|\\n", "", html_name)
+    return(clean_name)
   })
-  names(list) <- unlist(list_names_html)
-  return(list)
+  names(option) <- unlist(choice_names_html)
+  return(option)
+}
+
+# Convert option list to choiceNames and choiceValues with HTML support
+choice_list_html <- function(option) {
+  choice_names <- lapply(names(option), function(name) {
+    html_name <- markdown_to_html(name)
+    # Remove paragraph tags but keep other HTML formatting
+    clean_name <- gsub("<[/]?p>|\\n", "", html_name)
+    return(shiny::HTML(clean_name))
+  })
+  choice_values <- as.list(unname(option))
+  return(list(names = choice_names, values = choice_values))
 }
 
 #' Display Package Information on Attach
@@ -1460,11 +1472,6 @@ sd_create_translations <- function(language = "en", path = getwd()) {
   invisible(NULL)
 }
 
-# Helper function to check if error is GSSAPI-related
-is_gssapi_error <- function(error_msg) {
-  grepl("invalid response to GSSAPI negotiation", error_msg, ignore.case = TRUE)
-}
-
 # Helper function to try database connection with specific gssencmode
 try_db_connection <- function(params, gss_mode) {
   # Build connection arguments
